==> haskell-hls-qualify-imported-names-plugin-2.1.0.0-99-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-qualify-imported-names-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-qualify-imported-names-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-qualify-imported-names-plugin-2.1.0.0-8EEOjeTLw4d3GI29Frv6SL

key:
    hls-qualify-imported-names-plugin-2.1.0.0-8EEOjeTLw4d3GI29Frv6SL

license:              Apache-2.0
maintainer:           shenjonathan0@gmail.com
author:               Jonathan Shen
synopsis:
    A Haskell Language Server plugin that qualifies imported names

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  f6335dec14328e3ef4542960ea47472c
exposed:              True
exposed-modules:      Ide.Plugin.QualifyImportedNames
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-qualify-imported-names-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-qualify-imported-names-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-qualify-imported-names-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-qualify-imported-names-plugin
hs-libraries:
    HShls-qualify-imported-names-plugin-2.1.0.0-8EEOjeTLw4d3GI29Frv6SL

depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 dlist-1.0-B7D1vsARFiIHVaGk5CGbYO ghc-9.6.6
    ghcide-2.1.0.0-BlCpiz4ZHvtIqUTiKV6UyX
    hls-graph-2.1.0.0-5t3ebukJcC8H3T2BKlhdh9
    hls-plugin-api-2.1.0.0-IyHsVCiLch7D25xEM5t6Zs
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html/hls-qualify-imported-names-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-qualify-imported-names-plugin-2.1.0.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-qualify-imported-names-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-qualify-imported-names-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-qualify-imported-names-plugin-2.1.0.0-AsU2X2Sz0goD5u8LDdeFln

key:
    hls-qualify-imported-names-plugin-2.1.0.0-AsU2X2Sz0goD5u8LDdeFln

license:              Apache-2.0
maintainer:           shenjonathan0@gmail.com
author:               Jonathan Shen
synopsis:
    A Haskell Language Server plugin that qualifies imported names

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  1fe02ea52c9a3cf935fb299c03224eed
exposed:              True
exposed-modules:      Ide.Plugin.QualifyImportedNames
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-qualify-imported-names-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-qualify-imported-names-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-qualify-imported-names-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-qualify-imported-names-plugin
hs-libraries:
    HShls-qualify-imported-names-plugin-2.1.0.0-AsU2X2Sz0goD5u8LDdeFln

depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 dlist-1.0-B7D1vsARFiIHVaGk5CGbYO ghc-9.6.6
    ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hls-graph-2.1.0.0-2K7OAPbw31L8NzoSrWGIDe
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html/hls-qualify-imported-names-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
